==> tseries_0.5-2.tar.gz: tseries/data/nino.R <==
if (!require (ts, quietly=TRUE))
  stop (paste("Package ts is needed (It should be installed automatically\n",
              "      for version 0.65.0 and later). Stopping"))
nino3 <- ts(c(
23.97,
24.51,
26.65,
26.65,
25.91,
25.64,
25.17,
24.51,
24.12,
24.32,
23.80,
24.44,
25.10,
26.55,
26.58,
27.67,
27.04,
26.46,
26.54,
25.96,
25.45,
25.88,
25.96,
25.99,
25.91,
26.69,
26.95,
27.56,
26.64,
25.75,
25.12,
24.85,
24.59,
24.62,
24.53,
24.45,
25.92,
26.81,
27.41,
28.23,
27.44,
26.90,
26.04,
25.12,
25.69,
25.13,
25.28,
25.36,
25.77,
26.40,
27.05,
26.25,
26.02,
25.33,
24.46,
23.73,
23.75,
23.82,
24.06,
24.13,
24.58,
26.26,
26.28,
26.90,
25.58,
25.32,
24.93,
24.19,
23.10,
23.21,
22.70,
23.60,
24.28,
25.94,
26.49,
26.89,
26.65,
26.03,
24.93,
24.22,
23.88,
24.43,
23.90,
24.38,
24.80,
26.41,
27.35,
27.93,
27.55,
27.22,
26.59,
26.34,
25.31,
25.60,
26.19,
26.68,
27.09,
27.37,
27.78,
27.73,
27.03,
26.60,
25.74,
25.09,
24.21,
24.59,
24.78,
25.14,
25.50,
26.43,
26.79,
27.58,
26.94,
26.03,
24.96,
24.32,
24.26,
24.72,
24.77,
24.91,
25.53,
25.92,
26.96,
27.32,
26.62,
25.97,
25.37,
24.89,
24.82,
24.25,
24.12,
24.66,
25.10,
26.42,
26.88,
27.55,
26.92,
26.62,
24.82,
24.27,
23.61,
23.97,
24.36,
24.87,
25.34,
26.11,
26.52,
26.61,
26.25,
25.97,
25.31,
24.94,
24.21,
24.27,
24.10,
24.15,
25.05,
25.81,
26.94,
27.58,
26.96,
26.67,
26.43,
25.85,
25.44,
25.55,
25.76,
26.05,
26.01,
26.34,
26.66,
26.42,
25.40,
25.04,
24.88,
23.81,
23.94,
24.12,
23.88,
23.69,
24.80,
26.08,
26.97,
27.68,
27.61,
27.19,
26.75,
26.20,
26.03,
26.18,
26.39,
26.64,
26.78,
26.88,
27.11,
27.54,
26.22,
26.20,
25.49,
24.65,
24.17,
24.50,
24.25,
24.29,
25.13,
26.21,
26.41,
26.53,
26.76,
26.54,
25.13,
24.24,
23.66,
23.80,
23.98,
24.22,
24.49,
24.91,
25.94,
26.70,
26.13,
26.15,
25.90,
25.27,
24.95,
25.11,
25.32,
25.73,
26.37,
26.74,
27.69,
27.89,
28.02,
27.09,
25.80,
25.50,
25.44,
25.66,
25.73,
26.26,
26.54,
26.57,
26.93,
27.46,
26.37,
25.37,
23.88,
23.55,
23.57,
23.68,
23.42,
23.40,
24.35,
24.95,
26.17,
26.69,
26.37,
25.71,
25.11,
24.14,
23.94,
23.91,
23.90,
23.94,
25.12,
26.19,
26.98,
27.91,
27.66,
27.41,
27.03,
26.87,
26.35,
26.80,
27.12,
27.50,
27.37,
27.39,
27.37,
26.89,
26.12,
25.34,
24.39,
23.65,
23.60,
23.57,
23.47,
23.55,
23.97,
25.16,
26.39,
26.83,
26.49,
26.15,
25.51,
24.77,
24.35,
24.15,
24.06,
24.24,
25.18,
25.73,
26.57,
27.11,
26.00,
25.24,
24.77,
24.14,
23.69,
23.40,
23.72,
23.38,
23.83,
25.39,
26.49,
26.90,
26.89,
26.88,
26.23,
25.79,
25.78,
25.84,
25.80,
25.85,
26.47,
26.82,
27.42,
27.00,
26.94,
26.46,
25.50,
24.57,
24.70,
25.26,
25.36,
25.34,
25.99,
26.26,
26.95,
26.68,
26.23,
25.61,
24.93,
24.35,
24.26,
24.58,
24.80,
25.36,
25.40,
26.26,
27.27,
27.63,
27.16,
26.75,
25.46,
25.02,
25.83,
25.26,
25.25,
25.48,
26.06,
26.54,
26.92,
27.38,
27.13,
26.87,
25.58,
24.70,
24.95,
24.66,
25.12,
25.57,
25.05,
25.60,
26.80,
26.94,
26.74,
26.24,
25.08,
24.02,
24.67,
24.92,
24.79,
25.44,
25.87,
26.38,
26.96,
27.66,
27.76,
27.46,
26.47,
26.15,
26.57,
27.17,
27.62,
28.36,
28.94,
29.02,
29.12,
29.16,
29.03,
28.24,
26.69,
25.91,
25.23,
24.57,
24.23,
24.43,
24.81,
26.18,
27.10,
27.36,
26.47,
25.39,
24.97,
24.45,
24.30,
23.92,
24.04,
23.64,
24.53,
25.06,
26.10,
26.59,
26.12,
25.54,
24.79,
24.28,
24.05,
24.10,
24.20,
24.27,
24.67,
25.71,
26.84,
27.20,
26.70,
26.26,
25.66,
25.02,
25.27,
25.55,
25.88,
25.86,
26.64,
27.44,
28.18,
28.46,
28.23,
27.73,
27.10,
26.56,
26.61,
26.19,
26.14,
26.16,
26.09,
26.53,
27.19,
26.74,
25.30,
24.41,
23.70,
23.35,
23.57,
23.16,
23.05,
23.13,
24.11,
25.61,
25.99,
26.70,
26.43,
26.10,
25.32,
24.59,
24.46,
24.50,
24.57,
24.70,
25.25,
26.31,
27.03,
27.76,
27.39,
26.51,
25.47,
25.03,
24.89,
24.91,
24.80,
25.05,
25.62,
26.27,
27.08,
27.29,
27.62,
27.41,
26.53,
25.37,
24.93,
25.54,
26.01,
26.41,
26.99,
27.66,
28.33,
28.74,
28.38,
26.67,
25.54,
24.72,
24.47,
24.56,
24.68,
24.97,
25.46,
26.47,
27.51,
28.51,
28.21,
27.07,
25.79,
24.93,
24.92,
25.16,
25.09,
25.25,
25.67,
26.04,
26.86,
27.03,
27.00,
26.45,
25.17,
24.65,
24.78,
25.42,
25.80,
26.03,
26.32,
26.86,
27.05,
27.07,
26.35,
26.10,
25.37,
24.31,
23.96,
24.02,
23.94,
24.21,
24.95,
25.70,
26.77,
26.78,
26.32,
25.91,
25.38,
24.59,
24.33,
24.38,
24.37,
24.14,
24.72,
25.87,
27.09,
27.69,
28.16,
28.29,
28.10,
27.89,
27.85,
28.15,
28.50,
28.79,
28.90,
28.92,
29.13,
29.07,
28.16,
26.01,
25.24,
24.63,
24.19,
24.06,
24.10,
23.86,
24.40,
25.57,
26.67,
26.66,
26.44,
25.59,
24.85,
24.02,
23.72,
23.75),
start=c(1950,1), end=c(1999,10), frequency=12)
nino3.4 <- ts(c(
25.01,
24.92,
26.41,
26.75,
26.30,
26.79,
26.59,
26.11,
25.56,
26.03,
25.42,
25.54,
25.47,
26.62,
26.44,
27.74,
27.54,
27.53,
27.48,
27.44,
27.02,
27.40,
27.31,
27.19,
26.88,
27.03,
26.89,
28.12,
27.58,
27.06,
26.82,
26.83,
26.49,
26.70,
26.37,
25.99,
27.02,
27.09,
27.41,
28.40,
27.90,
27.87,
27.65,
26.82,
27.46,
26.91,
26.94,
26.43,
27.08,
26.95,
27.36,
27.38,
27.46,
27.06,
26.32,
25.65,
25.55,
25.80,
25.65,
25.53,
25.12,
26.27,
26.31,
27.01,
26.66,
26.72,
26.39,
25.92,
25.01,
24.83,
24.34,
25.05,
25.32,
26.18,
26.37,
26.91,
27.63,
27.16,
26.32,
25.98,
25.79,
26.30,
25.63,
26.20,
26.16,
26.88,
27.37,
28.16,
28.13,
27.91,
27.82,
27.97,
27.00,
27.39,
27.93,
28.08,
28.42,
28.24,
28.36,
28.21,
28.11,
28.10,
27.33,
27.22,
26.13,
26.70,
26.71,
27.02,
27.06,
27.30,
27.24,
27.96,
27.92,
27.37,
26.62,
26.33,
26.04,
26.52,
26.40,
26.39,
26.49,
26.35,
27.17,
27.84,
27.65,
27.35,
27.07,
26.90,
26.63,
26.28,
26.12,
26.31,
26.23,
26.61,
27.03,
27.76,
27.84,
28.05,
26.90,
26.45,
25.93,
26.03,
26.16,
26.28,
26.17,
26.36,
26.87,
27.28,
27.24,
27.41,
27.05,
26.81,
26.10,
26.17,
25.97,
25.83,
25.88,
26.19,
27.14,
27.83,
27.55,
27.61,
28.01,
27.62,
27.42,
27.59,
27.45,
27.58,
27.42,
27.14,
26.96,
27.07,
26.82,
26.58,
26.53,
26.00,
25.52,
25.83,
25.32,
25.38,
25.82,
26.41,
27.15,
27.75,
28.09,
28.27,
28.23,
28.05,
27.93,
28.16,
28.13,
28.31,
27.82,
27.67,
28.03,
28.39,
27.66,
28.03,
27.45,
26.79,
26.51,
26.51,
26.29,
26.17,
26.15,
26.42,
26.58,
26.87,
27.50,
27.74,
26.93,
26.48,
26.04,
26.09,
26.19,
26.11,
25.88,
25.77,
26.55,
27.28,
27.20,
27.60,
27.47,
27.14,
26.69,
26.92,
27.36,
27.27,
27.69,
27.81,
27.99,
28.17,
28.57,
28.09,
27.28,
27.33,
27.27,
27.44,
27.24,
27.62,
27.39,
27.10,
27.42,
28.14,
27.69,
27.10,
26.21,
25.83,
25.58,
25.41,
25.07,
24.64,
25.01,
25.27,
26.11,
26.64,
27.16,
26.93,
26.64,
26.24,
25.88,
25.92,
25.58,
25.61,
25.84,
26.49,
27.08,
28.08,
28.36,
28.34,
28.17,
28.14,
27.86,
28.38,
28.62,
28.61,
28.25,
27.98,
27.82,
27.53,
27.26,
26.70,
26.04,
25.66,
25.44,
25.25,
24.76,
24.58,
24.58,
25.21,
26.05,
26.90,
26.82,
27.18,
26.71,
26.30,
26.19,
25.87,
25.59,
25.78,
26.08,
26.33,
26.59,
27.15,
26.87,
26.41,
26.13,
25.55,
25.31,
25.07,
25.23,
24.82,
24.66,
25.61,
26.49,
26.99,
27.22,
27.39,
27.21,
27.07,
27.20,
27.58,
27.48,
27.21,
27.38,
27.03,
27.54,
27.58,
28.03,
27.86,
27.38,
26.85,
26.96,
27.30,
27.29,
27.16,
27.34,
26.93,
27.36,
27.22,
27.39,
27.11,
26.68,
26.13,
26.20,
26.41,
26.40,
26.53,
26.50,
26.69,
27.60,
27.88,
27.81,
27.76,
26.84,
26.69,
27.50,
26.87,
26.88,
27.04,
27.13,
27.18,
27.28,
27.86,
27.96,
28.12,
27.32,
26.59,
26.60,
26.51,
26.60,
26.91,
26.11,
26.16,
26.92,
27.28,
27.46,
27.41,
26.65,
26.01,
26.57,
26.80,
26.41,
26.58,
26.71,
26.68,
27.17,
27.97,
28.51,
28.73,
28.10,
27.96,
28.18,
28.72,
28.82,
29.17,
29.35,
29.23,
29.06,
28.93,
28.93,
28.30,
27.08,
26.55,
26.45,
25.84,
25.64,
25.57,
25.61,
26.34,
26.83,
27.40,
27.38,
26.87,
26.71,
26.29,
26.41,
25.90,
25.41,
24.93,
25.53,
25.55,
26.22,
26.88,
27.12,
26.94,
26.71,
26.46,
26.20,
26.14,
26.16,
26.17,
25.74,
25.88,
26.62,
27.45,
27.50,
27.65,
27.35,
27.18,
27.38,
27.55,
27.66,
27.68,
27.87,
28.02,
28.46,
28.76,
28.74,
29.01,
28.79,
28.60,
28.38,
28.08,
27.95,
27.57,
27.31,
27.19,
27.34,
27.31,
26.50,
26.10,
25.58,
25.22,
25.40,
24.66,
24.27,
24.36,
24.49,
25.32,
25.86,
26.68,
27.09,
27.01,
26.72,
26.36,
26.26,
26.25,
26.22,
26.35,
26.49,
26.87,
27.44,
28.03,
28.08,
27.62,
27.30,
27.05,
26.77,
26.95,
26.70,
26.86,
26.96,
26.91,
27.25,
27.96,
28.37,
28.39,
27.92,
27.36,
27.04,
27.69,
27.86,
28.33,
28.34,
28.60,
28.80,
29.16,
28.99,
28.08,
27.54,
26.71,
26.55,
26.40,
26.49,
26.74,
26.67,
26.94,
27.61,
28.59,
28.84,
28.27,
27.56,
26.87,
26.92,
26.95,
26.84,
26.73,
26.52,
26.54,
27.17,
27.81,
28.02,
27.91,
27.31,
27.31,
27.02,
27.38,
27.80,
27.83,
27.49,
27.45,
27.53,
27.90,
27.67,
27.52,
27.02,
26.38,
25.93,
25.67,
25.58,
25.57,
25.69,
25.80,
26.64,
27.39,
27.32,
27.34,
27.09,
26.55,
26.33,
26.23,
26.18,
25.97,
25.94,
26.37,
27.11,
28.08,
28.63,
28.97,
28.92,
28.84,
28.93,
29.24,
29.28,
29.24,
29.09,
28.86,
28.66,
28.54,
28.45,
26.72,
25.94,
25.49,
25.61,
25.34,
25.18,
24.78,
24.89,
25.41,
26.24,
26.84,
26.97,
26.59,
26.34,
25.59,
25.70,
25.63),
start=c(1950,1), end=c(1999,10), frequency=12)
nino <- ts.union (nino3, nino3.4)

==> tseries_0.8-2.tar.gz: tseries/data/nino.R <==
if (!require (ts, quietly=TRUE))
  stop ("Package ts is needed. Stopping")
nino3 <- ts(c(
23.97,
24.51,
26.65,
26.65,
25.91,
25.64,
25.17,
24.51,
24.12,
24.32,
23.80,
24.44,
25.10,
26.55,
26.58,
27.67,
27.04,
26.46,
26.54,
25.96,
25.45,
25.88,
25.96,
25.99,
25.91,
26.69,
26.95,
27.56,
26.64,
25.75,
25.12,
24.85,
24.59,
24.62,
24.53,
24.45,
25.92,
26.81,
27.41,
28.23,
27.44,
26.90,
26.04,
25.12,
25.69,
25.13,
25.28,
25.36,
25.77,
26.40,
27.05,
26.25,
26.02,
25.33,
24.46,
23.73,
23.75,
23.82,
24.06,
24.13,
24.58,
26.26,
26.28,
26.90,
25.58,
25.32,
24.93,
24.19,
23.10,
23.21,
22.70,
23.60,
24.28,
25.94,
26.49,
26.89,
26.65,
26.03,
24.93,
24.22,
23.88,
24.43,
23.90,
24.38,
24.80,
26.41,
27.35,
27.93,
27.55,
27.22,
26.59,
26.34,
25.31,
25.60,
26.19,
26.68,
27.09,
27.37,
27.78,
27.73,
27.03,
26.60,
25.74,
25.09,
24.21,
24.59,
24.78,
25.14,
25.50,
26.43,
26.79,
27.58,
26.94,
26.03,
24.96,
24.32,
24.26,
24.72,
24.77,
24.91,
25.53,
25.92,
26.96,
27.32,
26.62,
25.97,
25.37,
24.89,
24.82,
24.25,
24.12,
24.66,
25.10,
26.42,
26.88,
27.55,
26.92,
26.62,
24.82,
24.27,
23.61,
23.97,
24.36,
24.87,
25.34,
26.11,
26.52,
26.61,
26.25,
25.97,
25.31,
24.94,
24.21,
24.27,
24.10,
24.15,
25.05,
25.81,
26.94,
27.58,
26.96,
26.67,
26.43,
25.85,
25.44,
25.55,
25.76,
26.05,
26.01,
26.34,
26.66,
26.42,
25.40,
25.04,
24.88,
23.81,
23.94,
24.12,
23.88,
23.69,
24.80,
26.08,
26.97,
27.68,
27.61,
27.19,
26.75,
26.20,
26.03,
26.18,
26.39,
26.64,
26.78,
26.88,
27.11,
27.54,
26.22,
26.20,
25.49,
24.65,
24.17,
24.50,
24.25,
24.29,
25.13,
26.21,
26.41,
26.53,
26.76,
26.54,
25.13,
24.24,
23.66,
23.80,
23.98,
24.22,
24.49,
24.91,
25.94,
26.70,
26.13,
26.15,
25.90,
25.27,
24.95,
25.11,
25.32,
25.73,
26.37,
26.74,
27.69,
27.89,
28.02,
27.09,
25.80,
25.50,
25.44,
25.66,
25.73,
26.26,
26.54,
26.57,
26.93,
27.46,
26.37,
25.37,
23.88,
23.55,
23.57,
23.68,
23.42,
23.40,
24.35,
24.95,
26.17,
26.69,
26.37,
25.71,
25.11,
24.14,
23.94,
23.91,
23.90,
23.94,
25.12,
26.19,
26.98,
27.91,
27.66,
27.41,
27.03,
26.87,
26.35,
26.80,
27.12,
27.50,
27.37,
27.39,
27.37,
26.89,
26.12,
25.34,
24.39,
23.65,
23.60,
23.57,
23.47,
23.55,
23.97,
25.16,
26.39,
26.83,
26.49,
26.15,
25.51,
24.77,
24.35,
24.15,
24.06,
24.24,
25.18,
25.73,
26.57,
27.11,
26.00,
25.24,
24.77,
24.14,
23.69,
23.40,
23.72,
23.38,
23.83,
25.39,
26.49,
26.90,
26.89,
26.88,
26.23,
25.79,
25.78,
25.84,
25.80,
25.85,
26.47,
26.82,
27.42,
27.00,
26.94,
26.46,
25.50,
24.57,
24.70,
25.26,
25.36,
25.34,
25.99,
26.26,
26.95,
26.68,
26.23,
25.61,
24.93,
24.35,
24.26,
24.58,
24.80,
25.36,
25.40,
26.26,
27.27,
27.63,
27.16,
26.75,
25.46,
25.02,
25.83,
25.26,
25.25,
25.48,
26.06,
26.54,
26.92,
27.38,
27.13,
26.87,
25.58,
24.70,
24.95,
24.66,
25.12,
25.57,
25.05,
25.60,
26.80,
26.94,
26.74,
26.24,
25.08,
24.02,
24.67,
24.92,
24.79,
25.44,
25.87,
26.38,
26.96,
27.66,
27.76,
27.46,
26.47,
26.15,
26.57,
27.17,
27.62,
28.36,
28.94,
29.02,
29.12,
29.16,
29.03,
28.24,
26.69,
25.91,
25.23,
24.57,
24.23,
24.43,
24.81,
26.18,
27.10,
27.36,
26.47,
25.39,
24.97,
24.45,
24.30,
23.92,
24.04,
23.64,
24.53,
25.06,
26.10,
26.59,
26.12,
25.54,
24.79,
24.28,
24.05,
24.10,
24.20,
24.27,
24.67,
25.71,
26.84,
27.20,
26.70,
26.26,
25.66,
25.02,
25.27,
25.55,
25.88,
25.86,
26.64,
27.44,
28.18,
28.46,
28.23,
27.73,
27.10,
26.56,
26.61,
26.19,
26.14,
26.16,
26.09,
26.53,
27.19,
26.74,
25.30,
24.41,
23.70,
23.35,
23.57,
23.16,
23.05,
23.13,
24.11,
25.61,
25.99,
26.70,
26.43,
26.10,
25.32,
24.59,
24.46,
24.50,
24.57,
24.70,
25.25,
26.31,
27.03,
27.76,
27.39,
26.51,
25.47,
25.03,
24.89,
24.91,
24.80,
25.05,
25.62,
26.27,
27.08,
27.29,
27.62,
27.41,
26.53,
25.37,
24.93,
25.54,
26.01,
26.41,
26.99,
27.66,
28.33,
28.74,
28.38,
26.67,
25.54,
24.72,
24.47,
24.56,
24.68,
24.97,
25.46,
26.47,
27.51,
28.51,
28.21,
27.07,
25.79,
24.93,
24.92,
25.16,
25.09,
25.25,
25.67,
26.04,
26.86,
27.03,
27.00,
26.45,
25.17,
24.65,
24.78,
25.42,
25.80,
26.03,
26.32,
26.86,
27.05,
27.07,
26.35,
26.10,
25.37,
24.31,
23.96,
24.02,
23.94,
24.21,
24.95,
25.70,
26.77,
26.78,
26.32,
25.91,
25.38,
24.59,
24.33,
24.38,
24.37,
24.14,
24.72,
25.87,
27.09,
27.69,
28.16,
28.29,
28.10,
27.89,
27.85,
28.15,
28.50,
28.79,
28.90,
28.92,
29.13,
29.07,
28.16,
26.01,
25.24,
24.63,
24.19,
24.06,
24.10,
23.86,
24.40,
25.57,
26.67,
26.66,
26.44,
25.59,
24.85,
24.02,
23.72,
23.75),
start=c(1950,1), end=c(1999,10), frequency=12)
nino3.4 <- ts(c(
25.01,
24.92,
26.41,
26.75,
26.30,
26.79,
26.59,
26.11,
25.56,
26.03,
25.42,
25.54,
25.47,
26.62,
26.44,
27.74,
27.54,
27.53,
27.48,
27.44,
27.02,
27.40,
27.31,
27.19,
26.88,
27.03,
26.89,
28.12,
27.58,
27.06,
26.82,
26.83,
26.49,
26.70,
26.37,
25.99,
27.02,
27.09,
27.41,
28.40,
27.90,
27.87,
27.65,
26.82,
27.46,
26.91,
26.94,
26.43,
27.08,
26.95,
27.36,
27.38,
27.46,
27.06,
26.32,
25.65,
25.55,
25.80,
25.65,
25.53,
25.12,
26.27,
26.31,
27.01,
26.66,
26.72,
26.39,
25.92,
25.01,
24.83,
24.34,
25.05,
25.32,
26.18,
26.37,
26.91,
27.63,
27.16,
26.32,
25.98,
25.79,
26.30,
25.63,
26.20,
26.16,
26.88,
27.37,
28.16,
28.13,
27.91,
27.82,
27.97,
27.00,
27.39,
27.93,
28.08,
28.42,
28.24,
28.36,
28.21,
28.11,
28.10,
27.33,
27.22,
26.13,
26.70,
26.71,
27.02,
27.06,
27.30,
27.24,
27.96,
27.92,
27.37,
26.62,
26.33,
26.04,
26.52,
26.40,
26.39,
26.49,
26.35,
27.17,
27.84,
27.65,
27.35,
27.07,
26.90,
26.63,
26.28,
26.12,
26.31,
26.23,
26.61,
27.03,
27.76,
27.84,
28.05,
26.90,
26.45,
25.93,
26.03,
26.16,
26.28,
26.17,
26.36,
26.87,
27.28,
27.24,
27.41,
27.05,
26.81,
26.10,
26.17,
25.97,
25.83,
25.88,
26.19,
27.14,
27.83,
27.55,
27.61,
28.01,
27.62,
27.42,
27.59,
27.45,
27.58,
27.42,
27.14,
26.96,
27.07,
26.82,
26.58,
26.53,
26.00,
25.52,
25.83,
25.32,
25.38,
25.82,
26.41,
27.15,
27.75,
28.09,
28.27,
28.23,
28.05,
27.93,
28.16,
28.13,
28.31,
27.82,
27.67,
28.03,
28.39,
27.66,
28.03,
27.45,
26.79,
26.51,
26.51,
26.29,
26.17,
26.15,
26.42,
26.58,
26.87,
27.50,
27.74,
26.93,
26.48,
26.04,
26.09,
26.19,
26.11,
25.88,
25.77,
26.55,
27.28,
27.20,
27.60,
27.47,
27.14,
26.69,
26.92,
27.36,
27.27,
27.69,
27.81,
27.99,
28.17,
28.57,
28.09,
27.28,
27.33,
27.27,
27.44,
27.24,
27.62,
27.39,
27.10,
27.42,
28.14,
27.69,
27.10,
26.21,
25.83,
25.58,
25.41,
25.07,
24.64,
25.01,
25.27,
26.11,
26.64,
27.16,
26.93,
26.64,
26.24,
25.88,
25.92,
25.58,
25.61,
25.84,
26.49,
27.08,
28.08,
28.36,
28.34,
28.17,
28.14,
27.86,
28.38,
28.62,
28.61,
28.25,
27.98,
27.82,
27.53,
27.26,
26.70,
26.04,
25.66,
25.44,
25.25,
24.76,
24.58,
24.58,
25.21,
26.05,
26.90,
26.82,
27.18,
26.71,
26.30,
26.19,
25.87,
25.59,
25.78,
26.08,
26.33,
26.59,
27.15,
26.87,
26.41,
26.13,
25.55,
25.31,
25.07,
25.23,
24.82,
24.66,
25.61,
26.49,
26.99,
27.22,
27.39,
27.21,
27.07,
27.20,
27.58,
27.48,
27.21,
27.38,
27.03,
27.54,
27.58,
28.03,
27.86,
27.38,
26.85,
26.96,
27.30,
27.29,
27.16,
27.34,
26.93,
27.36,
27.22,
27.39,
27.11,
26.68,
26.13,
26.20,
26.41,
26.40,
26.53,
26.50,
26.69,
27.60,
27.88,
27.81,
27.76,
26.84,
26.69,
27.50,
26.87,
26.88,
27.04,
27.13,
27.18,
27.28,
27.86,
27.96,
28.12,
27.32,
26.59,
26.60,
26.51,
26.60,
26.91,
26.11,
26.16,
26.92,
27.28,
27.46,
27.41,
26.65,
26.01,
26.57,
26.80,
26.41,
26.58,
26.71,
26.68,
27.17,
27.97,
28.51,
28.73,
28.10,
27.96,
28.18,
28.72,
28.82,
29.17,
29.35,
29.23,
29.06,
28.93,
28.93,
28.30,
27.08,
26.55,
26.45,
25.84,
25.64,
25.57,
25.61,
26.34,
26.83,
27.40,
27.38,
26.87,
26.71,
26.29,
26.41,
25.90,
25.41,
24.93,
25.53,
25.55,
26.22,
26.88,
27.12,
26.94,
26.71,
26.46,
26.20,
26.14,
26.16,
26.17,
25.74,
25.88,
26.62,
27.45,
27.50,
27.65,
27.35,
27.18,
27.38,
27.55,
27.66,
27.68,
27.87,
28.02,
28.46,
28.76,
28.74,
29.01,
28.79,
28.60,
28.38,
28.08,
27.95,
27.57,
27.31,
27.19,
27.34,
27.31,
26.50,
26.10,
25.58,
25.22,
25.40,
24.66,
24.27,
24.36,
24.49,
25.32,
25.86,
26.68,
27.09,
27.01,
26.72,
26.36,
26.26,
26.25,
26.22,
26.35,
26.49,
26.87,
27.44,
28.03,
28.08,
27.62,
27.30,
27.05,
26.77,
26.95,
26.70,
26.86,
26.96,
26.91,
27.25,
27.96,
28.37,
28.39,
27.92,
27.36,
27.04,
27.69,
27.86,
28.33,
28.34,
28.60,
28.80,
29.16,
28.99,
28.08,
27.54,
26.71,
26.55,
26.40,
26.49,
26.74,
26.67,
26.94,
27.61,
28.59,
28.84,
28.27,
27.56,
26.87,
26.92,
26.95,
26.84,
26.73,
26.52,
26.54,
27.17,
27.81,
28.02,
27.91,
27.31,
27.31,
27.02,
27.38,
27.80,
27.83,
27.49,
27.45,
27.53,
27.90,
27.67,
27.52,
27.02,
26.38,
25.93,
25.67,
25.58,
25.57,
25.69,
25.80,
26.64,
27.39,
27.32,
27.34,
27.09,
26.55,
26.33,
26.23,
26.18,
25.97,
25.94,
26.37,
27.11,
28.08,
28.63,
28.97,
28.92,
28.84,
28.93,
29.24,
29.28,
29.24,
29.09,
28.86,
28.66,
28.54,
28.45,
26.72,
25.94,
25.49,
25.61,
25.34,
25.18,
24.78,
24.89,
25.41,
26.24,
26.84,
26.97,
26.59,
26.34,
25.59,
25.70,
25.63),
start=c(1950,1), end=c(1999,10), frequency=12)
nino <- ts.union (nino3, nino3.4)
